# frozen_string_literal: true

if defined?(RSpec) && (ENV['RACK_ENV'] == 'test' || ENV['RAILS_ENV'] == 'test')
  require 'jsonschema/matchers/match_jsonschema'
end

require 'jsonschema/matchers/version'
require 'jsonschema/matchers/metadater'
require 'jsonschema/generator'

NO_SCHEMA_NAME_ERROR = 'No schema name provided'

require 'jsonschema/matchers/configuration'

module Jsonschema
  # Main
  module Matchers
    class Error < StandardError; end

    class << self
      attr_writer :configuration
    end

    def self.configuration
      @configuration ||= Configuration.new
    end

    def self.configure
      yield(configuration)
    end

    def match_jsonschema(name: nil)
      schema_name = name || inspect.scan(/\"(.*?)\"/).join

      raise Error, NO_SCHEMA_NAME_ERROR unless schema_name

      MatchJsonschema.new(self.class.metadata, schema_name)
    end
  end
end
