# frozen_string_literal: true

require 'json-schema'

module Jsonschema
  module Matchers
    # Match Jsonschema snapshot
    class MatchJsonschema
      attr_reader :metadata, :path, :name, :errors

      def initialize(metadata, name)
        @metadata = metadata
        @path = "#{root_dir}/#{Metadater.call(metadata)}"
        @name = name.downcase.gsub(%r{[\/\s]}, '/' => '_', ' ' => '_')
      end

      def matches?(actual)
        file_full_path = "#{path}/#{name}.json"
        record(actual) unless File.exist?(file_full_path)
        file = File.open(file_full_path)

        @errors = JSON::Validator.fully_validate(file.path, actual)
        errors.empty?
      end

      def failure_message
        errors.join("\n")
      end

      private

      def root_dir
        Jsonschema::Matchers.configuration.schema_dir
      end

      def record(actual)
        json_schema = Jsonschema::Generator.call(actual)
        file_name = "#{name}.json"
        snap_path = File.join(path, file_name)

        unless Dir.exist?(File.dirname(snap_path))
          FileUtils.mkdir_p(File.dirname(snap_path))
        end

        file = File.new(snap_path, 'w+')
        file.write(JSON.pretty_generate(json_schema))
        file.close
      end
    end
  end
end

RSpec.configure do |config|
  config.include Jsonschema::Matchers
end
